| specialized_models | R Documentation |
Fits sparse logistic regression, nuclear-norm low-rank matrix recovery, and Bayesian Lasso linear regression models using the p-HMC algorithm, matching the case studies in Section VI of Shukla, Vats, and Chi (2025).
phmc_logistic(
X,
y,
alpha = 1,
lambda_g = 0.01,
n_draws = 2000,
epsilon = 0.002,
L = 10,
...
)
phmc_matrix(
X,
alpha = 1,
sigma_sq = 1,
lambda_g = 1e-04,
n_draws = 1000,
epsilon = 0.001,
L = 10,
...
)
phmc_lasso(
X,
y,
alpha = 1,
sigma_sq = 1,
lambda_g = 0.01,
n_draws = 2000,
epsilon = 0.005,
L = 10,
...
)
X |
Numeric design matrix (for regression models) or observed noisy matrix (for matrix recovery). |
y |
Numeric binary response vector for logistic regression or continuous response vector for Lasso. |
alpha |
Numeric scalar > 0. Regularization penalty parameter (default 1.0). |
lambda_g |
Numeric scalar > 0. Moreau-Yosida envelope regularization parameter. |
n_draws |
Integer > 0. Total number of MCMC iterations. |
epsilon |
Numeric scalar > 0. Step size parameter. |
L |
Integer >= 1. Number of leapfrog steps. |
... |
Additional arguments passed to |
sigma_sq |
Numeric scalar > 0. Error variance parameter (default 1.0). |
An object of class "phmc", which is a list containing posterior MCMC draws, parameter summary estimates matrix, log-likelihood, information criteria (AIC, BIC, DIC), acceptance rate, and execution metadata. See phmc for detailed descriptions of the list elements and output meaning.
Shukla A, Vats D, Chi EC (2025). “Proximal Hamiltonian Monte Carlo.” arXiv preprint, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.48550/arXiv.2510.22252")}.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.